@@ -10,8 +10,9 @@
 #' close_connection(conn)
 #' @return The given timestamp converted to a SQL-backend dependent timestamp
 #' @export
-db_timestamp <- function(timestamp, conn) {
-  UseMethod("db_timestamp", conn)
+db_timestamp <- function(timestamp, conn = NULL) {
+  if (is.null(conn)) db_timestamp.NULL(timestamp, conn)
+  else UseMethod("db_timestamp", conn)
 }
 
 #' @rdname db_timestamp
@@ -21,13 +22,20 @@ db_timestamp.default <- function(timestamp, conn) {
   return(dbplyr::translate_sql(as.POSIXct(!!timestamp), con = conn))
 }
 
+#' @rdname db_timestamp
+#' @export
+db_timestamp.NULL <- function(timestamp, conn) {
+  if (inherits(timestamp, "POSIXt")) timestamp <- format(timestamp)
+  return(timestamp)
+}
+
 #' @rdname db_timestamp
 #' @export
 db_timestamp.SQLiteConnection <- function(timestamp, conn) {
   if (is.na(timestamp)) {
-    dbplyr::translate_sql(NA_character_, con = conn)
+    return(dbplyr::translate_sql(NA_character_, con = conn))
   } else {
     if (inherits(timestamp, "POSIXt")) timestamp <- format(timestamp)
-    dbplyr::translate_sql(!!strftime(timestamp), con = conn)
+    return(dbplyr::translate_sql(!!strftime(timestamp), con = conn))
   }
 }
